==> gradio-4.44.0.tar.gz: gradio-4.44.0/js/box/CHANGELOG.md <==
# @gradio/box

## 0.1.25

### Fixes

- [#9163](https://github.com/gradio-app/gradio/pull/9163) [`2b6cbf2`](https://github.com/gradio-app/gradio/commit/2b6cbf25908e42cf027324e54ef2cc0baad11a91) - fix exports and generate types.  Thanks @pngwn!

### Dependency updates

- @gradio/atoms@0.8.1

## 0.1.24

### Features

- [#9118](https://github.com/gradio-app/gradio/pull/9118) [`e1c404d`](https://github.com/gradio-app/gradio/commit/e1c404da1143fb52b659d03e028bdba1badf443d) - setup npm-previews of all packages.  Thanks @pngwn!

### Dependency updates

- @gradio/atoms@0.8.0

## 0.1.23

### Dependency updates

- @gradio/atoms@0.7.9

## 0.1.22

### Dependency updates

- @gradio/atoms@0.7.8

## 0.1.21

### Dependency updates

- @gradio/atoms@0.7.7

## 0.1.20

### Dependency updates

- @gradio/atoms@0.7.6

## 0.1.19

### Dependency updates

- @gradio/atoms@0.7.5

## 0.1.18

### Dependency updates

- @gradio/atoms@0.7.4

## 0.1.17

### Dependency updates

- @gradio/atoms@0.7.3

## 0.1.16

### Dependency updates

- @gradio/atoms@0.7.2

## 0.1.15

### Dependency updates

- @gradio/atoms@0.7.1

## 0.1.14

### Dependency updates

- @gradio/atoms@0.7.0

## 0.1.13

### Dependency updates

- @gradio/atoms@0.6.2

## 0.1.12

### Dependency updates

- @gradio/atoms@0.6.1

## 0.1.11

### Dependency updates

- @gradio/atoms@0.6.0

## 0.1.10

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.5.3

## 0.1.9

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.5.2

## 0.1.8

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.5.1

## 0.1.7

### Patch Changes

- Updated dependencies [[`c60ad4d`](https://github.com/gradio-app/gradio/commit/c60ad4d34ab5b56a89bf6796822977e51e7a4a32)]:
  - @gradio/atoms@0.5.0

## 0.1.6

### Patch Changes

- Updated dependencies [[`73268ee`](https://github.com/gradio-app/gradio/commit/73268ee2e39f23ebdd1e927cb49b8d79c4b9a144)]:
  - @gradio/atoms@0.4.1

## 0.1.5

### Patch Changes

- Updated dependencies [[`4d1cbbc`](https://github.com/gradio-app/gradio/commit/4d1cbbcf30833ef1de2d2d2710c7492a379a9a00)]:
  - @gradio/atoms@0.4.0

## 0.1.4

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.3.1

## 0.1.3

### Patch Changes

- Updated dependencies [[`9caddc17b`](https://github.com/gradio-app/gradio/commit/9caddc17b1dea8da1af8ba724c6a5eab04ce0ed8)]:
  - @gradio/atoms@0.3.0

## 0.1.2

### Patch Changes

- Updated dependencies [[`f816136a0`](https://github.com/gradio-app/gradio/commit/f816136a039fa6011be9c4fb14f573e4050a681a)]:
  - @gradio/atoms@0.2.2

## 0.1.1

### Patch Changes

- Updated dependencies [[`3cdeabc68`](https://github.com/gradio-app/gradio/commit/3cdeabc6843000310e1a9e1d17190ecbf3bbc780), [`fad92c29d`](https://github.com/gradio-app/gradio/commit/fad92c29dc1f5cd84341aae417c495b33e01245f)]:
  - @gradio/atoms@0.2.1

## 0.1.0

### Features

- [#5498](https://github.com/gradio-app/gradio/pull/5498) [`287fe6782`](https://github.com/gradio-app/gradio/commit/287fe6782825479513e79a5cf0ba0fbfe51443d7) - Publish all components to npm. Thanks [@pngwn](https://github.com/pngwn)!

## 0.1.0-beta.7

### Patch Changes

- Updated dependencies [[`667802a6c`](https://github.com/gradio-app/gradio/commit/667802a6cdbfb2ce454a3be5a78e0990b194548a), [`c476bd5a5`](https://github.com/gradio-app/gradio/commit/c476bd5a5b70836163b9c69bf4bfe068b17fbe13)]:
  - @gradio/atoms@0.2.0-beta.6

## 0.1.0-beta.6

### Features

- [#6016](https://github.com/gradio-app/gradio/pull/6016) [`83e947676`](https://github.com/gradio-app/gradio/commit/83e947676d327ca2ab6ae2a2d710c78961c771a0) - Format js in v4 branch. Thanks [@freddyaboulton](https://github.com/freddyaboulton)!

## 0.1.0-beta.5

### Features

- [#5960](https://github.com/gradio-app/gradio/pull/5960) [`319c30f3f`](https://github.com/gradio-app/gradio/commit/319c30f3fccf23bfe1da6c9b132a6a99d59652f7) - rererefactor frontend files. Thanks [@pngwn](https://github.com/pngwn)!
- [#5938](https://github.com/gradio-app/gradio/pull/5938) [`13ed8a485`](https://github.com/gradio-app/gradio/commit/13ed8a485d5e31d7d75af87fe8654b661edcca93) - V4: Use beta release versions for '@gradio' packages. Thanks [@freddyaboulton](https://github.com/freddyaboulton)!
- [#5949](https://github.com/gradio-app/gradio/pull/5949) [`1c390f101`](https://github.com/gradio-app/gradio/commit/1c390f10199142a41722ba493a0c86b58245da15) - Merge main again. Thanks [@pngwn](https://github.com/pngwn)!

## 0.0.7

### Patch Changes

- Updated dependencies [[`e70805d54`](https://github.com/gradio-app/gradio/commit/e70805d54cc792452545f5d8eccc1aa0212a4695)]:
  - @gradio/atoms@0.2.0

## 0.0.6

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.1.4

## 0.0.5

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.1.3

## 0.0.4

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.1.2

## 0.0.3

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.1.1

## 0.0.2

### Features

- [#5215](https://github.com/gradio-app/gradio/pull/5215) [`fbdad78a`](https://github.com/gradio-app/gradio/commit/fbdad78af4c47454cbb570f88cc14bf4479bbceb) - Lazy load interactive or static variants of a component individually, rather than loading both variants regardless. This change will improve performance for many applications. Thanks [@pngwn](https://github.com/pngwn)!

==> gradio-5.0.0b1.tar.gz: gradio-5.0.0b1/js/box/CHANGELOG.md <==
# @gradio/box

## 0.1.25-beta.1

### Dependency updates

- @gradio/atoms@0.8.1-beta.1

## 0.1.25-beta.0

### Fixes

- [#9163](https://github.com/gradio-app/gradio/pull/9163) [`2b6cbf2`](https://github.com/gradio-app/gradio/commit/2b6cbf25908e42cf027324e54ef2cc0baad11a91) - fix exports and generate types.  Thanks @pngwn!

### Dependency updates

- @gradio/atoms@0.8.1-beta.0

## 0.1.24

### Features

- [#9118](https://github.com/gradio-app/gradio/pull/9118) [`e1c404d`](https://github.com/gradio-app/gradio/commit/e1c404da1143fb52b659d03e028bdba1badf443d) - setup npm-previews of all packages.  Thanks @pngwn!

### Dependency updates

- @gradio/atoms@0.8.0

## 0.1.23

### Dependency updates

- @gradio/atoms@0.7.9

## 0.1.22

### Dependency updates

- @gradio/atoms@0.7.8

## 0.1.21

### Dependency updates

- @gradio/atoms@0.7.7

## 0.1.20

### Dependency updates

- @gradio/atoms@0.7.6

## 0.1.19

### Dependency updates

- @gradio/atoms@0.7.5

## 0.1.18

### Dependency updates

- @gradio/atoms@0.7.4

## 0.1.17

### Dependency updates

- @gradio/atoms@0.7.3

## 0.1.16

### Dependency updates

- @gradio/atoms@0.7.2

## 0.1.15

### Dependency updates

- @gradio/atoms@0.7.1

## 0.1.14

### Dependency updates

- @gradio/atoms@0.7.0

## 0.1.13

### Dependency updates

- @gradio/atoms@0.6.2

## 0.1.12

### Dependency updates

- @gradio/atoms@0.6.1

## 0.1.11

### Dependency updates

- @gradio/atoms@0.6.0

## 0.1.10

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.5.3

## 0.1.9

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.5.2

## 0.1.8

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.5.1

## 0.1.7

### Patch Changes

- Updated dependencies [[`c60ad4d`](https://github.com/gradio-app/gradio/commit/c60ad4d34ab5b56a89bf6796822977e51e7a4a32)]:
  - @gradio/atoms@0.5.0

## 0.1.6

### Patch Changes

- Updated dependencies [[`73268ee`](https://github.com/gradio-app/gradio/commit/73268ee2e39f23ebdd1e927cb49b8d79c4b9a144)]:
  - @gradio/atoms@0.4.1

## 0.1.5

### Patch Changes

- Updated dependencies [[`4d1cbbc`](https://github.com/gradio-app/gradio/commit/4d1cbbcf30833ef1de2d2d2710c7492a379a9a00)]:
  - @gradio/atoms@0.4.0

## 0.1.4

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.3.1

## 0.1.3

### Patch Changes

- Updated dependencies [[`9caddc17b`](https://github.com/gradio-app/gradio/commit/9caddc17b1dea8da1af8ba724c6a5eab04ce0ed8)]:
  - @gradio/atoms@0.3.0

## 0.1.2

### Patch Changes

- Updated dependencies [[`f816136a0`](https://github.com/gradio-app/gradio/commit/f816136a039fa6011be9c4fb14f573e4050a681a)]:
  - @gradio/atoms@0.2.2

## 0.1.1

### Patch Changes

- Updated dependencies [[`3cdeabc68`](https://github.com/gradio-app/gradio/commit/3cdeabc6843000310e1a9e1d17190ecbf3bbc780), [`fad92c29d`](https://github.com/gradio-app/gradio/commit/fad92c29dc1f5cd84341aae417c495b33e01245f)]:
  - @gradio/atoms@0.2.1

## 0.1.0

### Features

- [#5498](https://github.com/gradio-app/gradio/pull/5498) [`287fe6782`](https://github.com/gradio-app/gradio/commit/287fe6782825479513e79a5cf0ba0fbfe51443d7) - Publish all components to npm. Thanks [@pngwn](https://github.com/pngwn)!

## 0.1.0-beta.7

### Patch Changes

- Updated dependencies [[`667802a6c`](https://github.com/gradio-app/gradio/commit/667802a6cdbfb2ce454a3be5a78e0990b194548a), [`c476bd5a5`](https://github.com/gradio-app/gradio/commit/c476bd5a5b70836163b9c69bf4bfe068b17fbe13)]:
  - @gradio/atoms@0.2.0-beta.6

## 0.1.0-beta.6

### Features

- [#6016](https://github.com/gradio-app/gradio/pull/6016) [`83e947676`](https://github.com/gradio-app/gradio/commit/83e947676d327ca2ab6ae2a2d710c78961c771a0) - Format js in v4 branch. Thanks [@freddyaboulton](https://github.com/freddyaboulton)!

## 0.1.0-beta.5

### Features

- [#5960](https://github.com/gradio-app/gradio/pull/5960) [`319c30f3f`](https://github.com/gradio-app/gradio/commit/319c30f3fccf23bfe1da6c9b132a6a99d59652f7) - rererefactor frontend files. Thanks [@pngwn](https://github.com/pngwn)!
- [#5938](https://github.com/gradio-app/gradio/pull/5938) [`13ed8a485`](https://github.com/gradio-app/gradio/commit/13ed8a485d5e31d7d75af87fe8654b661edcca93) - V4: Use beta release versions for '@gradio' packages. Thanks [@freddyaboulton](https://github.com/freddyaboulton)!
- [#5949](https://github.com/gradio-app/gradio/pull/5949) [`1c390f101`](https://github.com/gradio-app/gradio/commit/1c390f10199142a41722ba493a0c86b58245da15) - Merge main again. Thanks [@pngwn](https://github.com/pngwn)!

## 0.0.7

### Patch Changes

- Updated dependencies [[`e70805d54`](https://github.com/gradio-app/gradio/commit/e70805d54cc792452545f5d8eccc1aa0212a4695)]:
  - @gradio/atoms@0.2.0

## 0.0.6

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.1.4

## 0.0.5

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.1.3

## 0.0.4

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.1.2

## 0.0.3

### Patch Changes

- Updated dependencies []:
  - @gradio/atoms@0.1.1

## 0.0.2

### Features

- [#5215](https://github.com/gradio-app/gradio/pull/5215) [`fbdad78a`](https://github.com/gradio-app/gradio/commit/fbdad78af4c47454cbb570f88cc14bf4479bbceb) - Lazy load interactive or static variants of a component individually, rather than loading both variants regardless. This change will improve performance for many applications. Thanks [@pngwn](https://github.com/pngwn)!
